define("epi-cms/contentediting/FuturePublishingDateNotification", [
// dojo
    "dojo/_base/declare",
    "dojo/Stateful",
    "dojo/string",

// dijit
    "dijit/Destroyable",

// epi
    "epi/datetime",
    "epi-cms/contentediting/ContentActionSupport",

// resources
    "epi/i18n!epi/cms/nls/episerver.cms.contentediting.futurepublishingdate"
], function (
// dojo
    declare,
    Stateful,
    string,

// dijit
    Destroyable,

// epi
    datetime,
    ContentActionSupport,

// resources
    resources
) {

    return declare([Stateful, Destroyable], {
        // summary:
        //      Show message if the page is published and the date is set to the "future"
        // tags:
        //      internal

        // notification: [public] Object
        //      Notification object format: { content: "notification message" }
        notification: null,

        postscript: function () {
            this.inherited(arguments);
            this.own(
                this.watch("invokeActionValue", this._invokeActionPropertyWatchHandler.bind(this))
            );
        },

        _invokeActionPropertyWatchHandler: function (name, oldValue, value) {
            // summary:
            //      Updates the notification when the property changes.
            // tags:
            //      private
            var contentData = value && value.contentData;

            if (contentData.status === ContentActionSupport.versionStatus.Published) {

                var publishedDate = new Date(contentData.properties.iversionable_startpublish);

                if (publishedDate.getTime() > datetime.serverTime()) {

                    var message = string.substitute(resources.message, [datetime.toUserFriendlyHtml(publishedDate)]);

                    this.set("notification", { content: message });
                    return;
                }
            }
            this.set("notification", null);
        }
    });
});
